# MilkTea Package

[![PyPI version](https://badge.fury.io/py/milktea.svg)](https://badge.fury.io/py/tba)  [![codecov](https://codecov.io/gh/doerlbh/milktea/branch/main/graph/badge.svg?token=)](https://codecov.io/gh/doerlbh/tba)  [![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

Python library for multi-modal intergration of real-time patient interactions with tabular embedding alignment (TEA).

Created by [Baihan Lin](https://www.baihan.nyc), Columbia University
